<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<defaultcodec>windows-1251</defaultcodec>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QFontDatabase</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demi Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oblique</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thai</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lao</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simplified Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Korean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vietnamese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symbol</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Runic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N&apos;Ko</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wr&amp;iting System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation type="unfinished"></translation>
    </message>
</context>

<context>
    <name>Details</name>
    <message>
        <location filename="../../ui/details.ui" line="23"/>
        <source>Information for station</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../ui/mainwindow.ui" line="148"/>
        <location filename="../../ui/mainwindow.ui" line="601"/>
        <source>Find</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="241"/>
        <source>Waiting time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="283"/>
        <source>Time to station:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="329"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="456"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="470"/>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="474"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="489"/>
        <source>&amp;View</source>
        <translation>&amp;Vues</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="500"/>
        <source>&amp;Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="604"/>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="619"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="622"/>
        <source>Alt+Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="634"/>
        <source>Save As...</source>
        <translation>Enregistrer sous...</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="637"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="649"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="652"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="661"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="664"/>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="684"/>
        <location filename="../../ui/mainwindow.ui" line="687"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="699"/>
        <location filename="../../ui/mainwindow.ui" line="702"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="716"/>
        <source>Save scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="728"/>
        <source>Preference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="731"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="745"/>
        <source>Show time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="756"/>
        <source>Show hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="793"/>
        <source>Save position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="798"/>
        <source>Add maps...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="810"/>
        <source>Screen mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="813"/>
        <source>Alt+Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="785"/>
        <source>Transliterate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="427"/>
        <source>Routes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="765"/>
        <source>About...</source>
        <translation>À propos…</translation>
    </message>
    <message>
        <location filename="../../ui/mainwindow.ui" line="774"/>
        <source>Zoom to fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="372"/>
        <source>Open file</source>
        <translation>Ouvrir fichier</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="372"/>
        <source>Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save file</source>
        <translation type="obsolete">Enregistrer fichier</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">A propos</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="579"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="579"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="585"/>
        <source>Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="811"/>
        <source>Add maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.cpp" line="811"/>
        <source>1. Wait until loaded site...
2. Select map
3. Save file map here:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../../ui/settings.ui" line="26"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="94"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="133"/>
        <source>Custom font and style for station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="146"/>
        <source>Font and style for station name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="212"/>
        <source>Font...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="219"/>
        <source>Back color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="577"/>
        <source>Simple graphics for transfers*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/settings.cpp" line="46"/>
        <source>Color...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="257"/>
        <source>Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="292"/>
        <source>Upper case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="299"/>
        <source>Word wrap*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="454"/>
        <source>Full screen mode*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="337"/>
        <source>Transparency when drawing the route</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="444"/>
        <source>Show a scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="403"/>
        <source>Map back color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="410"/>
        <source>Scale of interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="497"/>
        <source>Performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="524"/>
        <source>Cache graphics to raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="534"/>
        <source>Show time to the stations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="544"/>
        <source>Show the background for map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="554"/>
        <source>Antialiasing filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="564"/>
        <source>Fast scrolling (without antialiasing)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="616"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="646"/>
        <source>Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="667"/>
        <source>Clean the cache on exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui/settings.ui" line="725"/>
        <source>Empty Now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TMapView</name>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="102"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="106"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="107"/>
        <source>Finish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="332"/>
        <source>Day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="332"/>
        <source>Night</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="332"/>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="332"/>
        <source>Rush Hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="447"/>
        <source>Cannot open file mapping:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1506"/>
        <source>line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1514"/>
        <source>Begin station:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1526"/>
        <source>Go to station:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1528"/>
        <source>Transfer to station:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1533"/>
        <source>Final station:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1540"/>
        <location filename="../../src/mapview/mapview.cpp" line="1545"/>
        <source>st.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1548"/>
        <source>Travel time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1550"/>
        <source>min.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1551"/>
        <source>transf.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/mapview/mapview.cpp" line="1782"/>
        <source>Save file</source>
        <translation type="unfinished">Enregistrer fichier</translation>
    </message>
</context>
<context>
    <name>UnZip</name>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1138"/>
        <source>ZIP operation completed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1139"/>
        <source>Failed to initialize or load zlib library.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1140"/>
        <source>zlib library error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1141"/>
        <source>Unable to create or open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1142"/>
        <source>Partially corrupted archive. Some files might be extracted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1143"/>
        <source>Corrupted archive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1144"/>
        <source>Wrong password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1145"/>
        <source>No archive has been created yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1146"/>
        <source>File or directory does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1147"/>
        <source>File read error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1148"/>
        <source>File write error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1149"/>
        <source>File seek error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1150"/>
        <source>Unable to create a directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1151"/>
        <source>Invalid device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1152"/>
        <source>Invalid or incompatible zip archive.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1153"/>
        <source>Inconsistent headers. Archive might be corrupted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/unzip.cpp" line="1157"/>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TMobileUi</name>
    <message>
        <location filename="../../src/mobileui.cpp" line="43"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../../src/about.h" line="26"/>
        <source>About</source>
        <translation type="unfinished">A propos</translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="61"/>
        <source>Unknown author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="62"/>
        <source>transit system map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="62"/>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="62"/>
        <source>Author of map file format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="63"/>
        <source>About current map file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="63"/>
        <source>This program uses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="64"/>
        <source>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="67"/>
        <source>Author of translation: Gusak Leonid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/about.h" line="88"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Zip</name>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1205"/>
        <source>ZIP operation completed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1206"/>
        <source>Failed to initialize or load zlib library.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1207"/>
        <source>zlib library error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1208"/>
        <source>Unable to create or open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1209"/>
        <source>No archive has been created yet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1210"/>
        <source>File or directory does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1211"/>
        <source>File read error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1212"/>
        <source>File write error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1213"/>
        <source>File seek error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/zip/zip.cpp" line="1217"/>
        <source>Unknown error.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
